Module blaxel.core.client.models.sandbox_definition
===================================================

Classes
-------

`SandboxDefinition(categories: blaxel.core.client.types.Unset | list[typing.Any] = <blaxel.core.client.types.Unset object>, coming_soon: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, display_name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, enterprise: blaxel.core.client.types.Unset | bool = <blaxel.core.client.types.Unset object>, icon: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, image: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, long_description: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, memory: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, name: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>, ports: blaxel.core.client.types.Unset | list['Port'] = <blaxel.core.client.types.Unset object>, url: blaxel.core.client.types.Unset | str = <blaxel.core.client.types.Unset object>)`
:   Sandbox definition for admin store operations
    
    Attributes:
        categories (Union[Unset, list[Any]]): Categories of the defintion
        coming_soon (Union[Unset, bool]): If the definition is coming soon
        description (Union[Unset, str]): Description of the defintion
        display_name (Union[Unset, str]): Display name of the definition
        enterprise (Union[Unset, bool]): If the definition is enterprise
        icon (Union[Unset, str]): Icon of the definition
        image (Union[Unset, str]): Image of the Sandbox definition
        long_description (Union[Unset, str]): Long description of the defintion
        memory (Union[Unset, int]): Memory of the Sandbox definition in MB
        name (Union[Unset, str]): Name of the artifact
        ports (Union[Unset, list['Port']]): Set of ports for a resource
        url (Union[Unset, str]): URL of the definition
    
    Method generated by attrs for class SandboxDefinition.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `categories`
    :

    `coming_soon`
    :

    `description`
    :

    `display_name`
    :

    `enterprise`
    :

    `icon`
    :

    `image`
    :

    `long_description`
    :

    `memory`
    :

    `name`
    :

    `ports`
    :

    `url`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :